Advanced features of EspressoDB
===============================

EspressoDB provides certain features which help navigating complex table relations.
In this section we present

1. how consistency checks can be implemented to make it difficult to insert inconsistent data and
2. how tables can be written such that one can easily extend future scenarios.

.. toctree::
    :caption: Contents:

    consistency-checks
    pre-save
    init-checks
    model-specializations
